EasyDevStoryStyle class

Constructors

EasyDevStoryStyle({IndicatorStyle indicatorStyle = const IndicatorStyle(), SliderStyle sliderStyle = const SliderStyle(), EdgeInsetsGeometry margin = const EdgeInsets.only(left: 16, right: 16, bottom: 20), Color closeButtonColor = const Color(0xffffffff), Widget loadingScreen = const CircularLoadingIndicator(type: IndicatorType.medium), BorderRadius borderRadius = const BorderRadius.all(Radius.circular(8))})
Creates styles to use in the EasyDevStory.
const

Properties

borderRadius BorderRadius
Radius of rounding the corners of indicator around the story element in the slider.
final
closeButtonColor Color
Color of close button.
final
hashCode int
The hash code for this object.
no setterinherited
indicatorStyle IndicatorStyle
Story progress indicator style.
final
loadingScreen Widget
Custom loading screen widget. This is useful when you want to use your own loading screen.
final
margin EdgeInsetsGeometry
Empty space around the story.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sliderStyle SliderStyle
Styles for slider list.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited